# pybaseanal

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)                 
[![Python 3.10](https://img.shields.io/badge/python-3.10-blue.svg)](https://www.python.org/downloads/)   

## Functionality of the pybaseanal

- Importing basic libraries at once
- Perform basic data processing 
> - Null analysis
> - Graph plots
> - Data type conversion

## Usage

- To read dataframe
- To perform EDA
- To annalyse the null
```
pip install pybaseanal
```
##### For Null Values
- null_Analysis(data_df, null_Cuttoff = 25, headcount = 5)
- plot_categorical_frequency(df, output_path='cat_graph.docx')
- convert_columns_to_preferred_types(df)
- generate_visualizations_and_report(df, output_path='output.docx')

## Note 
- Please drop your suggestions on pydev@phaf.in 

## More Information
- Visit [pybaseanal.phaf.in](http://pybaseanal.phaf.in)
